/****************************************************************************
**
** This file is part of PLCEdit, an open-source cross-platform editor 
** for PLC source files (e.g. from Moeller, CoDeSys and Siemens).
** Copyright (C) 2005-2009  M. Rehfeldt
**
** This software uses classes of Trolltech Qt toolkit and is freeware. 
** This file may be used under the terms of the GNU General Public License 
** version 2.0 or (at your option) any later version as published by the 
** Free Software Foundation and appearing in the file LICENSE.GPL included 
** in the packaging of this file. 
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** Contact e-mail: M. Rehfeldt <info@plcedit.org>
** Program URL   : http://www.plcedit.org
**
****************************************************************************/


#include "editor.h"


Editor::Editor(QWidget *parent) 
  : QTextEdit(parent)
{ //! creating function

  //Thanks to: QtSoftware, S. Weinzierl and J. L. Biord
 
 
  setLineWrapMode(QTextEdit::NoWrap);			//set line wrap mode to NO
  setUndoRedoEnabled(true);						//set undo/redo enabled
  
  prefWidth = 45; //max. width of line numbers block
  setViewportMargins(prefWidth, 0, 0, 0);
  
  connect(verticalScrollBar(), 	SIGNAL(valueChanged(int)), 		this, SLOT(update()));
  connect(this, 				SIGNAL(textChanged()), 			this, SLOT(update()));

}


Editor::~Editor()
{ //! destructor

}


bool Editor::event(QEvent *event) 
{ //! line numbers block paint event
  
  if (event->type()==QEvent::Paint) 
  {
    QPainter p(this);
    p.fillRect(0, 0, prefWidth, height(), QColor(255, 250, 205)); //lines rect., lemon chiffon 
    p.fillRect(prefWidth, 0, 3, height(), QColor(192, 192, 192)); //sep. rect.. grey
    //good colors: 	
    //				(255, 255, 192) - light yellow 		(yellow)
    //				(255, 250, 205) - lemon chiffon 	(yellow)
    //				(222, 184, 135) - burly wood 		(brown)
    //				(255, 192, 192) - light red 		(red)
    // 				(255, 225, 255) - thistle1  		(red)
    //				(240, 230, 140) - khaki 			(green)
    // 				(193, 255, 193) - DarkSeaGreen1		(green)
    //				(224, 255, 255) - light cyan 		(blue)
    //				(202, 225, 255) - light steel blue1 (blue)
    //				(192, 192, 192) - grey 				(grey)
    //				(240, 255, 240) - honney dew 		(grey)


    int contentsY = verticalScrollBar()->value();
    qreal pageBottom = contentsY + viewport()->height();
    int m_lineNumber(1);
    
    const QFontMetrics fm=fontMetrics();
    const int ascent = fontMetrics().ascent() + 1;

    for (QTextBlock block=document()->begin(); block.isValid(); block=block.next(), m_lineNumber++) 
    {
      QTextLayout *layout = block.layout();
      const QRectF boundingRect = layout->boundingRect();
      QPointF position = layout->position();
      if ( position.y() + boundingRect.height() < contentsY )
        continue;
      if ( position.y() > pageBottom ) 
        break;
      const QString txt = QString::number(m_lineNumber);
      p.drawText(prefWidth-fm.width(txt)-3, qRound(position.y())-contentsY + ascent, txt); 
    }
  }
  
  return QTextEdit::event(event);
}


void Editor::paintEvent(QPaintEvent *event)
{ //! painter event
  
  //first reset background color of editor to white
  QPalette editorPalette = palette();
  editorPalette.setColor(QPalette::Base, QColor(255, 255, 255));
  setPalette(editorPalette);
  viewport()->update();

  //set painter
  QPainter painter(viewport());
  
  //set lines highlighter
  if (enableHighlightLines == true)
  {
    QRect r = cursorRect();
    r.setX(0);
    r.setWidth(viewport()->width());
    painter.fillRect(r, QBrush(hiLineColor));
  }

  //set print area indicator
  if (printArea > 0) 
  {
    int x1=(printArea * 8), x2=x1, y1=0, y2= viewport()->height();
    /*test line: 111111111122222222223333333333444444444455555555556666666666777777777788888888889999999999*/ 
    QLine line = QLine(x1, y1, x2, y2);
    painter.setPen(Qt::DotLine);
    painter.drawLine(line);
  }

  painter.end();
  QTextEdit::paintEvent(event);

}
