/****************************************************************************
**
** This file is part of PLCEdit, an open-source cross-platform editor 
** for PLC source files (e.g. from Moeller, CoDeSys and Siemens).
** Copyright (C) 2005-2009  M. Rehfeldt
**
** This software uses classes of Trolltech Qt toolkit and is freeware. 
** This file may be used under the terms of the GNU General Public License 
** version 2.0 or (at your option) any later version as published by the 
** Free Software Foundation and appearing in the file LICENSE.GPL included 
** in the packaging of this file. 
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** Contact e-mail: M. Rehfeldt <info@plcedit.org>
** Program URL   : http://www.plcedit.org
**
****************************************************************************/


#include <QtGui>

#include "pathextdialog.h"


PathExtDialog::PathExtDialog(QDialog *parent) 
 : QDialog(parent)
{ //! creating function
	
	setupUi(this);
    retranslateUi();
    	 
	setWindowFlags( Qt::Tool | Qt::WindowStaysOnTopHint );
	
	//diverse connections
  	connect(PED_pushButton_path, SIGNAL(clicked()), this, SLOT(PathDlg()));		//get Path
  
  	//set Button sizes
	#ifdef Q_WS_MAC	
  	//do nothing for Mac OS
	#else
 	 PED_pushButton_close->setMinimumHeight(25);
 	 PED_pushButton_close->setMaximumHeight(25);
  	 PED_pushButton_ok->setMinimumHeight(25);
 	 PED_pushButton_ok->setMaximumHeight(25);
	#endif  	

}


PathExtDialog::~PathExtDialog()
{ //! virtual destructor
}


void PathExtDialog::presetPath(QString dir)
{ //! preset line edit "path"
  
  PED_lineEdit_path->setText(QFileInfo(dir.simplified()).absolutePath() + "/");
}
		

void PathExtDialog::PathDlg()
{ //! get path from FileDialog and set into line edit "path"
 
  PED_lineEdit_path->setText(QFileDialog::getExistingDirectory(this, msg_head_pathdialog, "/home", QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks)  + "/");
}


QString PathExtDialog::currentPath()
{ //! get current path from line edit "path"

  return(QFileInfo(PED_lineEdit_path->text().simplified()).absolutePath() + "/"); 
}


QString PathExtDialog::currentExt()
{ //! get current file extension from comboBox "compatibility"
	
  return(PED_comboBox_compatibility->currentText().simplified());	
}


void PathExtDialog::retranslateUi()
{ //! retranslate Ui

  this->setWindowTitle(tr("Batch converter"));
	
  //ok Button
  PED_pushButton_ok->setText(tr("Ok"));
  PED_pushButton_ok->setStatusTip(tr("Accept inputs and close window"));
  PED_pushButton_ok->setToolTip(PED_pushButton_ok->statusTip());
  
  //close Button
  PED_pushButton_close->setText(tr("Close"));
  PED_pushButton_close->setStatusTip(tr("Cancel settings and close window"));
  PED_pushButton_close->setToolTip(PED_pushButton_close->statusTip());
  
  //label DIR
  PED_label_path->setText(tr("Result path:"));
  PED_label_path->setStatusTip(tr("Set a path for file storage"));
  PED_label_path->setToolTip(PED_label_path->statusTip());
  //line edit DIR
  PED_lineEdit_path->setStatusTip(PED_label_path->statusTip());
  PED_lineEdit_path->setToolTip(PED_lineEdit_path->statusTip());
  //push button DIR
  PED_pushButton_path->setStatusTip(PED_label_path->statusTip());
  PED_pushButton_path->setToolTip(PED_pushButton_path->statusTip());
  
  //label compatibility
  PED_label_compatibility->setText(tr("Compatibility:"));
  PED_label_compatibility->setStatusTip(tr("Select an extension for file conversion"));
  PED_label_compatibility->setToolTip(PED_label_compatibility->statusTip());
  //combobox compatibility
  PED_comboBox_compatibility->setStatusTip(PED_label_compatibility->statusTip());
  PED_comboBox_compatibility->setToolTip(PED_comboBox_compatibility->statusTip());  
  
  //messages
  msg_head_pathdialog = tr("Open Directory");
}
